@@ -3,6 +3,7 @@
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/agent/watcher.h>
+#include <net-snmp/agent/agent_callbacks.h>
 
 #include "agent/extend.h"
 #include "utilities/execute.h"
@@ -26,6 +27,7 @@ typedef struct extend_registration_block_s {
     size_t              oid_len;
     long                num_entries;
     netsnmp_extend     *ehead;
+    netsnmp_handler_registration       *reg[3];
     struct extend_registration_block_s *next;
 } extend_registration_block;
 extend_registration_block *ereg_head = NULL;
@@ -44,7 +46,7 @@ netsnmp_old_extend *compatability_entries;
 
 WriteMethod fixExec2Error;
 FindVarMethod var_extensible_old;
-oid  old_extensible_variables_oid[] = { UCDAVIS_MIB, SHELLMIBNUM, 1 };
+oid  old_extensible_variables_oid[] = { NETSNMP_UCDAVIS_MIB, NETSNMP_SHELLMIBNUM, 1 };
 struct variable2 old_extensible_variables[] = {
     {MIBINDEX,     ASN_INTEGER,   RONLY, var_extensible_old, 1, {MIBINDEX}},
     {ERRORNAME,    ASN_OCTET_STR, RONLY, var_extensible_old, 1, {ERRORNAME}},
@@ -117,6 +119,7 @@ _register_extend( oid *base, size_t len )
                 "nsExtendConfigTable", handle_nsExtendConfigTable, 
                 oid_buf, len+1, HANDLER_CAN_RWRITE);
     netsnmp_register_table_data( reg, dinfo, tinfo );
+    eptr->reg[0] = reg;
 
         /*
          * Register the main output table
@@ -133,6 +136,7 @@ _register_extend( oid *base, size_t len )
                 "nsExtendOut1Table", handle_nsExtendOutput1Table, 
                 oid_buf, len+1, HANDLER_CAN_RONLY);
     netsnmp_register_table_data( reg, dinfo, tinfo );
+    eptr->reg[1] = reg;
 
         /*
          * Register the multi-line output table
@@ -151,6 +155,7 @@ _register_extend( oid *base, size_t len )
                 "nsExtendOut2Table", handle_nsExtendOutput2Table, 
                 oid_buf, len+1, HANDLER_CAN_RONLY);
     netsnmp_register_table( reg, tinfo );
+    eptr->reg[2] = reg;
 
         /*
          * Register a watched scalar to keep track of the number of entries
@@ -167,6 +172,23 @@ _register_extend( oid *base, size_t len )
     return eptr;
 }
 
+int
+extend_clear_callback(int majorID, int minorID,
+                    void *serverarg, void *clientarg)
+{
+    extend_registration_block *eptr, *enext = NULL;
+
+    for ( eptr=ereg_head; eptr; eptr=enext ) {
+        enext=eptr->next;
+        netsnmp_unregister_handler( eptr->reg[0] );
+        netsnmp_unregister_handler( eptr->reg[1] );
+        netsnmp_unregister_handler( eptr->reg[2] );
+        SNMP_FREE(eptr);
+    }
+    ereg_head = NULL;
+    return 0;
+}
+
 void init_extend( void )
 {
     snmpd_register_config_handler("extend",    extend_parse_config, NULL, NULL);
@@ -186,6 +208,10 @@ void init_extend( void )
     REGISTER_MIB("ucd-extensible", old_extensible_variables,
                  variable2, old_extensible_variables_oid);
 #endif
+
+    snmp_register_callback(SNMP_CALLBACK_APPLICATION,
+                           SNMPD_CALLBACK_PRE_UPDATE_CONFIG,
+                           extend_clear_callback, NULL);
 }
 
         /*************************
@@ -392,6 +418,11 @@ extend_parse_config(const char *token, char *cptr)
         oid_len = MAX_OID_LEN - 2;
         read_objid( exec_name, oid_buf, &oid_len );
         cptr = copy_nword(cptr, exec_name,    sizeof(exec_name));
+        if (!strcmp( token, "sh"   ) ||
+            !strcmp( token, "exec" )) {
+            config_perror("ERROR: This output format has been deprecated - Please use the 'extend' directive instead" );
+            return;
+        }
     } else {
         memcpy( oid_buf, ns_extend_oid, sizeof(ns_extend_oid));
         oid_len = OID_LENGTH(ns_extend_oid);
