@@ -40,10 +40,6 @@
 #include <winsock.h>
 #endif
 
-#if HAVE_DMALLOC_H
-#include <dmalloc.h>
-#endif
-
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/agent/agent_index.h>
@@ -227,7 +223,7 @@ agentx_register(netsnmp_session * ss, oid start[], size_t startlen,
     }
 
     if (response->errstat != SNMP_ERR_NOERROR) {
-        snmp_log(LOG_ERR,"registering pdu failed: %ld!\n", response->errstat);
+        snmp_log(LOG_ERR,"registering pdu failed: %d!\n", response->errstat);
         snmp_free_pdu(response);
         return 0;
     }
