@@ -39,15 +39,21 @@
 #include <stdlib.h>
 #endif
 
-#if defined(bsdi4) || defined(freebsd3) || defined(freebsd4) || defined(freebsd5)
-#if HAVE_GETFSSTAT
-#if defined(MFSNAMELEN)
+#if defined(aix4) || defined(aix5)
+#include <sys/mntctl.h>
+#include <sys/vmount.h>
+#include <sys/statfs.h>
+#endif
+
+#if defined(bsdi4) || defined(freebsd3) || defined(freebsd4) || defined(freebsd5) || defined(darwin)
+#if HAVE_GETFSSTAT && defined(MFSNAMELEN)
 #define MOUNT_NFS	"nfs"
 #define MNTTYPE_UFS	"ufs"
 #define BerkelyFS
 #define MNTTYPE_FFS	"ffs"
 #define MNTTYPE_NFS	"nfs"
 #define MNTTYPE_NFS3	"nfs"
+#define MNTTYPE_HFS	"hfs"
 #define MNTTYPE_MFS	"mfs"
 #define MNTTYPE_MSDOS	"msdos"
 #define MNTTYPE_LFS	"lfs"
@@ -65,7 +71,6 @@
 #define MNTTYPE_CFS	"coda"
 #define MNTTYPE_NTFS	"ntfs"
 #endif
-#endif
 #endif                          /* freebsd3 */
 
 #define HRFS_MONOTONICALLY_INCREASING
@@ -123,6 +128,17 @@ static int		fscount;
 #define HRFS_statfs	win_statfs
 #define	HRFS_type	f_type
 
+#elif defined(aix4) || defined(aix5)
+
+struct vmount *aixmnt, *aixcurr;
+struct HRFS_entry {
+	char *HRFS_name;
+	char *HRFS_mount;
+	int HRFS_type;
+	int HRFS_flags;
+} *HRFS_entry;
+#define HRFS_statfs statfs
+
 #else
 struct mntent  *HRFS_entry;
 #define	HRFS_name	mnt_fsname
@@ -186,6 +202,10 @@ init_hr_filesys(void)
 {
     REGISTER_MIB("host/hr_filesys", hrfsys_variables, variable4,
                  hrfsys_variables_oid);
+#if defined(aix4) || defined(aix5) /* something leaks, make it idiot-safe */
+    aixmnt = NULL;
+    aixcurr = NULL;
+#endif
 }
 
 /*
@@ -320,6 +340,9 @@ var_hrfilesys(struct variable *vp,
         case MOUNT_NFS:
             fsys_type_id[fsys_type_len - 1] = 14;
             break;
+        case MOUNT_HFS:
+            fsys_type_id[fsys_type_len - 1] = 7;
+            break;
         case MOUNT_MFS:
             fsys_type_id[fsys_type_len - 1] = 8;
             break;
@@ -373,17 +396,38 @@ var_hrfilesys(struct variable *vp,
             break;
 #endif
         }
+#elif defined(aix4) || defined(aix5)
+        switch (HRFS_entry->HRFS_type) {
+        case MNT_AIX:
+        case MNT_JFS:
+            fsys_type_id[fsys_type_len - 1] = 3;
+            break;
+        case MNT_CDROM:
+            fsys_type_id[fsys_type_len - 1] = 12;
+            break;
+#ifdef MNT_NAMEFS
+        case MNT_NAMEFS:
+#endif
+#ifdef MNT_PROCFS
+        case MNT_PROCFS:
+#endif
+        case MNT_SFS:
+        case MNT_CACHEFS:
+            fsys_type_id[fsys_type_len - 1] = 1;
+            break;
+        case MNT_NFS:
+        case MNT_NFS3:
+        case MNT_AUTOFS:
+            fsys_type_id[fsys_type_len - 1] = 14;
+            break;
+        }
 #else
         mnt_type = HRFS_entry->HRFS_type;
         if (mnt_type == NULL)
             fsys_type_id[fsys_type_len - 1] = 2;        /* unknown */
 #ifdef MNTTYPE_HFS
         else if (!strcmp(mnt_type, MNTTYPE_HFS))
-#ifdef BerkelyFS
-            fsys_type_id[fsys_type_len - 1] = 3;
-#else                           /* SysV */
-            fsys_type_id[fsys_type_len - 1] = 4;
-#endif
+            fsys_type_id[fsys_type_len - 1] = 7;
 #endif
 #ifdef MNTTYPE_UFS
         else if (!strcmp(mnt_type, MNTTYPE_UFS))
@@ -472,6 +516,8 @@ var_hrfilesys(struct variable *vp,
         long_return = HRFS_entry->f_flags & MNT_RDONLY ? 2 : 1;
 #elif defined(cygwin)
         long_return = 1;
+#elif defined(aix4) || defined(aix5)
+        long_return = (HRFS_entry->HRFS_flags & MNT_READONLY) == 0 ? 1 : 2;
 #else
         if (hasmntopt(HRFS_entry, "ro") != NULL)
             long_return = 2;    /* Read Only */
@@ -531,6 +577,29 @@ Init_HR_FileSys(void)
     getfsstat(fsstats, fscount * sizeof(*fsstats), MNT_NOWAIT);
 #endif
     HRFS_index = 0;
+#elif defined(aix4) || defined(aix5)
+    int ret;
+    uint size;
+    ret = 0;
+    size = 0;
+    if(aixmnt != NULL) free(aixmnt); /* something leaks, make it idiot-safe */
+    aixmnt = NULL;
+    aixcurr = NULL;
+    HRFS_index = 0;
+    ret = mntctl(MCTL_QUERY, sizeof(uint), &size);
+    if(ret == 0 && size > 0) {
+        aixmnt = malloc(size + sizeof(struct HRFS_entry));
+        if(aixmnt != NULL) {
+            HRFS_entry = (char *) aixmnt + size;
+            ret = mntctl(MCTL_QUERY, size, aixmnt);
+            HRFS_index = 1;
+            if(ret <= 0) {
+                free(aixmnt);
+                aixmnt = NULL;
+                HRFS_entry = NULL;
+            } else aixcurr = aixmnt;
+        }
+    }
 #else
     HRFS_index = 1;
     if (fp != NULL)
@@ -580,6 +649,31 @@ Get_Next_HR_FileSys(void)
         return -1;
     HRFS_entry = fsstats + HRFS_index;
     return ++HRFS_index;
+#elif defined(aix4) || defined(aix5)
+    if(aixcurr == NULL) {
+        if(aixmnt != NULL) free(aixmnt);
+        aixmnt = NULL;
+        HRFS_entry = NULL;
+        return -1;
+    }
+    HRFS_entry->HRFS_name = vmt2dataptr(aixcurr, VMT_OBJECT);
+    HRFS_entry->HRFS_mount = vmt2dataptr(aixcurr, VMT_STUB);
+    HRFS_entry->HRFS_type = aixcurr->vmt_gfstype;
+    HRFS_entry->HRFS_flags = aixcurr->vmt_flags;
+    aixcurr = (char *) aixcurr + aixcurr->vmt_length;
+    if((char *) aixcurr >= (char *) HRFS_entry) aixcurr = NULL;
+    switch(HRFS_entry->HRFS_type) {
+#ifdef MNT_NAMEFS
+        case MNT_NAMEFS:
+#endif
+#ifdef MNT_PROCFS
+        case MNT_PROCFS:
+#endif
+        case MNT_SFS:
+            return Get_Next_HR_FileSys();
+            break;
+    }
+    return HRFS_index++;
 #else
     const char    **cpp;
 
@@ -624,12 +718,11 @@ Get_Next_HR_FileSys(void)
 int
 Check_HR_FileSys_NFS (void)
 {
-#if HAVE_GETFSSTAT
-#if defined(MFSNAMELEN)
-    if (!strcmp(HRFS_entry->HRFS_type, MOUNT_NFS))
-#else
-    if (HRFS_entry->HRFS_type == MOUNT_NFS)
-#endif
+#if HAVE_GETFSSTAT && !defined(MFSNAMELEN)
+    if ((HRFS_entry->HRFS_type == MOUNT_NFS) ||
+        (HRFS_entry->HRFS_type == MOUNT_AFS))
+#elif defined(aix4) || defined(aix5)
+    if(HRFS_entry->HRFS_type == MNT_NFS || HRFS_entry->HRFS_type == MNT_NFS3)
 #else /* HAVE_GETFSSTAT */
     if ( HRFS_entry->HRFS_type != NULL && (
 #if defined(MNTTYPE_NFS)
@@ -638,20 +731,23 @@ Check_HR_FileSys_NFS (void)
 	!strcmp( HRFS_entry->HRFS_type, "nfs") ||
 #endif
 #if defined(MNTTYPE_NFS3)
-	    !strcmp( HRFS_entry->HRFS_type, MNTTYPE_NFS3) ||
+	!strcmp( HRFS_entry->HRFS_type, MNTTYPE_NFS3) ||
 #endif
 #if defined(MNTTYPE_SMBFS)
-	    !strcmp( HRFS_entry->HRFS_type, MNTTYPE_SMBFS) ||
+	!strcmp( HRFS_entry->HRFS_type, MNTTYPE_SMBFS) ||
 #endif
 #if defined(MNTTYPE_LOFS)
-	    !strcmp( HRFS_entry->HRFS_type, MNTTYPE_LOFS) ||
+	!strcmp( HRFS_entry->HRFS_type, MNTTYPE_LOFS) ||
+#endif
+#if defined(MNTTYPE_AFP)
+	!strcmp( HRFS_entry->HRFS_type, MNTTYPE_AFP) ||
 #endif
 	    /*
 	     * MVFS is Rational ClearCase's view file system
 	     * it is similiar to NFS file systems in that it is mounted
 	     * locally or remotely from the ClearCase server
 	     */
-	    !strcmp( HRFS_entry->HRFS_type, "mvfs")))
+	!strcmp( HRFS_entry->HRFS_type, "mvfs")))
 #endif /* HAVE_GETFSSTAT */
 	return 1;	/* NFS file system */
 
@@ -665,6 +761,13 @@ End_HR_FileSys(void)
     if (fsstats)
         free((char *) fsstats);
     fsstats = NULL;
+#elif defined(aix4) || defined(aix5)
+    if(aixmnt != NULL) {
+        free(aixmnt);
+        aixmnt = NULL;
+        aixcurr = NULL;
+        HRFS_entry = NULL;
+    }
 #else
     if (fp != NULL)
         fclose(fp);
