@@ -1,11 +1,16 @@
 /*
  * interface data access header
  *
- * $Id: interface.h,v 1.10 2004/11/16 23:42:03 rstory Exp $
+ * $Id: interface.h,v 1.16 2006/09/26 23:34:50 rstory Exp $
  */
 #ifndef NETSNMP_ACCESS_INTERFACE_CONFIG_H
 #define NETSNMP_ACCESS_INTERFACE_CONFIG_H
 
+/*
+ * all platforms use this generic code
+ */
+config_require(if-mib/data_access/interface)
+
 /**---------------------------------------------------------------------*/
 /*
  * configure required files
@@ -20,21 +25,32 @@
  *    HPUX11 had different reuirements than other HPUX, that should
  *    be handled in the *_hpux.h header file.
  */
-config_require(if-mib/data_access/interface_common)
-#if defined( linux )
-config_require(if-mib/data_access/interface_linux);
-config_require(if-mib/data_access/interface_ioctl);
+
+#ifdef NETSNMP_INCLUDE_IFTABLE_REWRITES
+
+config_exclude(mibII/interfaces)
+
+#   if defined( linux )
+
+    config_require(if-mib/data_access/interface_linux)
+    config_require(if-mib/data_access/interface_ioctl)
+
+#   elif defined( openbsd3 ) || defined( openbsd4 ) || \
+    defined( freebsd4 ) || defined( freebsd5 ) || defined( freebsd6 )
+
+    config_require(if-mib/data_access/interface_sysctl)
+
+#   elif defined( solaris2 )
+
+    config_require(if-mib/data_access/interface_solaris2)
+
+#   else
+
+    config_error(This platform does not yet support IF-MIB rewrites)
+
+#   endif
 #else
 #   define NETSNMP_ACCESS_INTERFACE_NOARCH 1
 #endif
 
-/*
- * since the configure script will pick up this header and include it in
- * mib_module_includes.h, but actual interface structure definitions which
- * are used in other headers are defined in net-snmp/data_access/interface.h,
- * we need to ignore the normal convention of not including headers in
- * a header, or we will not be able to compile.
- */
-#include <net-snmp/data_access/interface.h>
-
 #endif /* NETSNMP_ACCESS_INTERFACE_CONFIG_H */
