@@ -1,7 +1,7 @@
 /*
  * systemstats data access header
  *
- * $Id: systemstats.h,v 1.1 2004/07/10 18:05:44 rstory Exp $
+ * $Id: systemstats.h,v 1.2 2005/10/28 15:29:23 rstory Exp $
  */
 /**---------------------------------------------------------------------*/
 /*
@@ -17,14 +17,14 @@
  *    HPUX11 had different reuirements than other HPUX, that should
  *    be handled in the *_hpux.h header file.
  */
-config_require(ip-mib/data_access/systemstats_common);
+config_require(ip-mib/data_access/systemstats_common)
 #if defined( linux )
-config_require(ip-mib/data_access/systemstats_linux);
+config_require(ip-mib/data_access/systemstats_linux)
 #else
 /*
  * couldn't determine the correct file!
  * require a bogus file to generate an error.
  */
-configure_require(ip-mib/data_access/systemstats-unknown-arch);
+config_require(ip-mib/data_access/systemstats-unknown-arch);
 #endif
 
