@@ -1,7 +1,7 @@
 /*
  * tcpConn data access header
  *
- * $Id: tcpConn.h,v 1.2 2004/09/26 20:30:22 rstory Exp $
+ * $Id: tcpConn.h,v 1.4 2006/10/10 21:13:36 tanders Exp $
  */
 /**---------------------------------------------------------------------*/
 /*
@@ -17,9 +17,11 @@
  *    HPUX11 had different reuirements than other HPUX, that should
  *    be handled in the *_hpux.h header file.
  */
-config_require(tcp-mib/data_access/tcpConn_common);
+config_require(tcp-mib/data_access/tcpConn_common)
 #if defined( linux )
-config_require(tcp-mib/data_access/tcpConn_linux);
+config_require(tcp-mib/data_access/tcpConn_linux)
+#elif defined( solaris2 )
+config_require(tcp-mib/data_access/tcpConn_solaris2)
 #else
 #   define NETSNMP_TCPCONN_COMMON_ONLY
 #endif
