@@ -177,7 +177,7 @@ init_extensible(void)
      * registering underneath 
      */
     oid             extensible_variables_oid[] =
-        { UCDAVIS_MIB, SHELLMIBNUM, 1 };
+        { NETSNMP_UCDAVIS_MIB, NETSNMP_SHELLMIBNUM, 1 };
 
     /*
      * register ourselves with the agent to handle our mib tree 
@@ -220,7 +220,7 @@ extensible_parse_config(const char *token, char *cptr)
         /*
          * its a relocatable extensible mib 
          */
-        config_perror("WARNING: This output format is being deprecated - Please use the 'extend' directive instead" );
+        config_perror("WARNING: This output format has been deprecated - Please use the 'extend' directive instead" );
         for (pp = &relocs, numrelocs++; *pp; pp = &((*pp)->next));
         (*pp) = ptmp;
         pp = &relocs; scount = numrelocs;
@@ -270,19 +270,27 @@ extensible_parse_config(const char *token, char *cptr)
         strncpy(ptmp->command, cptr, tcptr - cptr);
         ptmp->command[tcptr - cptr] = 0;
     }
-#ifdef EXECFIXCMD
-    sprintf(ptmp->fixcmd, EXECFIXCMD, ptmp->name);
+#ifdef NETSNMP_EXECFIXCMD
+    sprintf(ptmp->fixcmd, NETSNMP_EXECFIXCMD, ptmp->name);
 #endif
     if (ptmp->miblen > 0) {
+      /*
+       * For relocatable "exec" entries,
+       * register the new (not-strictly-valid) MIB subtree...
+       */
         register_mib(token,
                      (struct variable *) extensible_relocatable_variables,
                      sizeof(struct variable2), 
                      sizeof(extensible_relocatable_variables) /
                      sizeof(*extensible_relocatable_variables),
                      ptmp->miboid, ptmp->miblen);
-    }
 
-    if (scount > 1) {
+      /*
+       * ... and ensure the entries are sorted by OID.
+       * This isn't needed for entries in the main extTable (which
+       * don't have MIB OIDs explicitly associated with them anyway)
+       */
+      if (scount > 1) {
         int i;
         struct extensible **etmp = (struct extensible **)
             malloc(((sizeof(struct extensible *)) * scount));
@@ -302,6 +310,7 @@ extensible_parse_config(const char *token, char *cptr)
         }
         ptmp->next = NULL;
         free(etmp);
+      }
     }
 }
 
