@@ -169,9 +169,9 @@ typedef long    fd_mask;
 /*
  * Globals.
  */
-#ifdef USE_LIBWRAP
+#ifdef NETSNMP_USE_LIBWRAP
 #include <tcpd.h>
-#endif                          /* USE_LIBWRAP */
+#endif                          /* NETSNMP_USE_LIBWRAP */
 
 #define TIMETICK         500000L
 
@@ -419,7 +419,7 @@ SnmpDaemonMain(int argc, TCHAR * argv[])
 main(int argc, char *argv[])
 #endif
 {
-    char            options[128] = "aAc:CdD::fhHI:l:L:m:M:n:p:P:qrsS:UvV-:";
+    char            options[128] = "aAc:CdD::fhHI:l:L:m:M:n:p:P:qrsS:UvV-:Y:";
     int             arg, i, ret;
     int             dont_fork = 0, do_help = 0;
     int             log_set = 0;
@@ -471,7 +471,7 @@ main(int argc, char *argv[])
     signal(SIGXFSZ, SnmpdCatchRandomSignal);
 #endif
 
-#ifdef NO_ROOT_ACCESS
+#ifdef NETSNMP_NO_ROOT_ACCESS
     /*
      * Default to no.  
      */
@@ -791,6 +791,10 @@ main(int argc, char *argv[])
 #endif
             break;
 
+        case 'Y':
+            netsnmp_config_remember(optarg);
+            break;
+
         default:
             usage(argv[0]);
             break;
@@ -836,9 +840,9 @@ main(int argc, char *argv[])
 					  NETSNMP_DS_AGENT_PORTS)));
     }
 
-#ifdef LOGFILE
+#ifdef NETSNMP_LOGFILE
     if (0 == log_set)
-        snmp_enable_filelog(LOGFILE,
+        snmp_enable_filelog(NETSNMP_LOGFILE,
                             netsnmp_ds_get_boolean(NETSNMP_DS_LIBRARY_ID,
                                                    NETSNMP_DS_LIB_APPEND_LOGFILES));
 #endif
@@ -912,16 +916,6 @@ main(int argc, char *argv[])
         Exit(1);                /*  Exit logs exit val for us  */
     }
 
-    /*
-     * Store persistent data immediately in case we crash later.  
-     */
-    snmp_store(app_name);
-
-    /*
-     * Send coldstart trap if possible.  
-     */
-    send_easy_trap(0, 0);
-
 #if HAVE_GETPID
     if (pid_file != NULL) {
         /*
@@ -951,6 +945,17 @@ main(int argc, char *argv[])
 #endif
 
 #if HAVE_UNISTD_H
+    cptr = get_persistent_directory();
+    mkdirhier( cptr, NETSNMP_AGENT_DIRECTORY_MODE, 0 );
+   
+    uid = netsnmp_ds_get_int(NETSNMP_DS_APPLICATION_ID, 
+			     NETSNMP_DS_AGENT_USERID);
+    gid = netsnmp_ds_get_int(NETSNMP_DS_APPLICATION_ID, 
+			     NETSNMP_DS_AGENT_GROUPID);
+    
+    if ( uid != 0 || gid != 0 )
+        chown( cptr, uid, gid );
+
 #ifdef HAVE_SETGID
     if ((gid = netsnmp_ds_get_int(NETSNMP_DS_APPLICATION_ID, 
 				  NETSNMP_DS_AGENT_GROUPID)) != 0) {
@@ -983,6 +988,16 @@ main(int argc, char *argv[])
 #endif
 #endif
 
+    /*
+     * Store persistent data immediately in case we crash later.  
+     */
+    snmp_store(app_name);
+
+    /*
+     * Send coldstart trap if possible.  
+     */
+    send_easy_trap(0, 0);
+
     /*
      * We're up, log our version number.  
      */
@@ -1059,6 +1074,9 @@ receive(void)
      */
     while (netsnmp_running) {
         if (reconfig) {
+#if HAVE_SIGHOLD
+            sighold(SIGHUP);
+#endif
             reconfig = 0;
             snmp_log(LOG_INFO, "Reconfiguring daemon\n");
 	    /*  Stop and restart logging.  This allows logfiles to be
@@ -1068,6 +1086,9 @@ receive(void)
 		     netsnmp_get_version());
             update_config();
             send_easy_trap(SNMP_TRAP_ENTERPRISESPECIFIC, 3);
+#if HAVE_SIGHOLD
+            sigrelse(SIGHUP);
+#endif
         }
 
         for (i = 0; i < NUM_EXTERNAL_SIGS; i++) {
