@@ -848,7 +848,7 @@ snmp_set_var_value(netsnmp_variable_list * vars,
             }
             else {
                 snmp_log(LOG_ERR,"bad size for integer-like type (%d)\n",
-                         vars->val_len);
+                         (int)vars->val_len);
                 return (1);
             }
         } else
@@ -904,25 +904,25 @@ snmp_set_var_value(netsnmp_variable_list * vars,
         vars->val.string = NULL;
         break;
 
-#ifdef OPAQUE_SPECIAL_TYPES
+#ifdef NETSNMP_WITH_OPAQUE_SPECIAL_TYPES
     case ASN_OPAQUE_U64:
     case ASN_OPAQUE_I64:
-#endif                          /* OPAQUE_SPECIAL_TYPES */
+#endif                          /* NETSNMP_WITH_OPAQUE_SPECIAL_TYPES */
     case ASN_COUNTER64:
         if (largeval) {
             snmp_log(LOG_ERR,"bad size for counter 64 (%d)\n",
-                     vars->val_len);
+                     (int)vars->val_len);
             return (1);
         }
         vars->val_len = sizeof(struct counter64);
         memmove(vars->val.counter64, value, vars->val_len);
         break;
 
-#ifdef OPAQUE_SPECIAL_TYPES
+#ifdef NETSNMP_WITH_OPAQUE_SPECIAL_TYPES
     case ASN_OPAQUE_FLOAT:
         if (largeval) {
             snmp_log(LOG_ERR,"bad size for opaque float (%d)\n",
-                     vars->val_len);
+                     (int)vars->val_len);
             return (1);
         }
         vars->val_len = sizeof(float);
@@ -932,14 +932,14 @@ snmp_set_var_value(netsnmp_variable_list * vars,
     case ASN_OPAQUE_DOUBLE:
         if (largeval) {
             snmp_log(LOG_ERR,"bad size for opaque double (%d)\n",
-                     vars->val_len);
+                     (int)vars->val_len);
             return (1);
         }
         vars->val_len = sizeof(double);
         memmove(vars->val.doubleVal, value, vars->val_len);
         break;
 
-#endif                          /* OPAQUE_SPECIAL_TYPES */
+#endif                          /* NETSNMP_WITH_OPAQUE_SPECIAL_TYPES */
 
     default:
         snmp_log(LOG_ERR,"no storage for OID\n");
@@ -1000,7 +1000,7 @@ snmp_synch_response_cb(netsnmp_session * ss,
     while (state->waiting) {
         numfds = 0;
         FD_ZERO(&fdset);
-        block = SNMPBLOCK;
+        block = NETSNMP_SNMPBLOCK;
         tvp = &timeout;
         timerclear(tvp);
         snmp_select_info(&numfds, &fdset, tvp, &block);
@@ -1079,7 +1079,7 @@ snmp_sess_synch_response(void *sessp,
     while (state->waiting) {
         numfds = 0;
         FD_ZERO(&fdset);
-        block = SNMPBLOCK;
+        block = NETSNMP_SNMPBLOCK;
         tvp = &timeout;
         timerclear(tvp);
         snmp_sess_select_info(sessp, &numfds, &fdset, tvp, &block);
