@@ -13,6 +13,7 @@
  */
 
 #include <net-snmp/net-snmp-config.h>
+#include <errno.h>
 
 #if HAVE_STDLIB_H
 #include <stdlib.h>
@@ -98,7 +99,7 @@ snmp_parse_args_descriptions(FILE * outf)
             "  -H\t\t\tdisplay configuration file directives understood\n");
     fprintf(outf, "  -v 1|2c|3\t\tspecifies SNMP version to use\n");
     fprintf(outf, "  -V, --version\t\tdisplay package version number\n");
-#if !defined(DISABLE_SNMPV1) || !defined(DISABLE_SNMPV2C)
+#if !defined(NETSNMP_DISABLE_SNMPV1) || !defined(NETSNMP_DISABLE_SNMPV2C)
     fprintf(outf, "SNMP Version 1 or 2c specific\n");
     fprintf(outf, "  -c COMMUNITY\t\tset the community string\n");
 #endif /* support for community based SNMP */
@@ -136,7 +137,7 @@ snmp_parse_args_descriptions(FILE * outf)
             "  -m MIB[:...]\t\tload given list of MIBs (ALL loads everything)\n");
     fprintf(outf,
             "  -M DIR[:...]\t\tlook in given list of directories for MIBs\n");
-#ifndef DISABLE_MIB_LOADING
+#ifndef NETSNMP_DISABLE_MIB_LOADING
     fprintf(outf,
             "  -P MIBOPTS\t\tToggle various defaults controlling MIB parsing:\n");
     snmp_mib_toggle_options_usage("\t\t\t  ", outf);
@@ -162,7 +163,7 @@ handle_long_opt(const char *myoptarg)
     /*
      * else it's a long option, so process it like name=value 
      */
-    cp = malloc(strlen(myoptarg) + 3);
+    cp = (char *)malloc(strlen(myoptarg) + 3);
     if (!cp)
         return;
     strcpy(cp, myoptarg);
@@ -269,7 +270,7 @@ snmp_parse_args(int argc,
             netsnmp_config_remember(optarg);
             break;
 
-#ifndef DISABLE_MIB_LOADING
+#ifndef NETSNMP_DISABLE_MIB_LOADING
         case 'm':
             setenv("MIBS", optarg, 1);
             break;
@@ -277,7 +278,7 @@ snmp_parse_args(int argc,
         case 'M':
             netsnmp_set_mib_directory(optarg);
             break;
-#endif /* DISABLE_MIB_LOADING */
+#endif /* NETSNMP_DISABLE_MIB_LOADING */
 
         case 'O':
             cp = snmp_out_toggle_options(optarg);
@@ -297,7 +298,7 @@ snmp_parse_args(int argc,
             }
             break;
 
-#ifndef DISABLE_MIB_LOADING
+#ifndef NETSNMP_DISABLE_MIB_LOADING
         case 'P':
             cp = snmp_mib_toggle_options(optarg);
             if (cp != NULL) {
@@ -306,7 +307,7 @@ snmp_parse_args(int argc,
                 return (-1);
             }
             break;
-#endif /* DISABLE_MIB_LOADING */
+#endif /* NETSNMP_DISABLE_MIB_LOADING */
 
         case 'D':
             debug_register_tokens(optarg);
@@ -320,12 +321,12 @@ snmp_parse_args(int argc,
 
         case 'v':
             session->version = -1;
-#ifndef DISABLE_SNMPV1
+#ifndef NETSNMP_DISABLE_SNMPV1
             if (!strcmp(optarg, "1")) {
                 session->version = SNMP_VERSION_1;
             }
 #endif
-#ifndef DISABLE_SNMPV2C
+#ifndef NETSNMP_DISABLE_SNMPV2C
             if (!strcasecmp(optarg, "2c")) {
                 session->version = SNMP_VERSION_2c;
             }
@@ -401,21 +402,32 @@ snmp_parse_args(int argc,
 #define SNMPV3_CMD_OPTIONS
 #ifdef  SNMPV3_CMD_OPTIONS
         case 'Z':
-            session->engineBoots = strtoul(optarg, NULL, 10);
-            if (session->engineBoots == 0 || !isdigit(optarg[0])) {
+            errno = 0;
+            session->engineBoots = strtoul(optarg, &cp, 10);
+            if (errno || cp == optarg) {
                 fprintf(stderr, "Need engine boots value after -Z flag.\n");
                 return (-1);
             }
-            cp = strchr(optarg, ',');
-            if (cp && *(++cp) && isdigit(*cp))
-                session->engineTime = strtoul(cp, NULL, 10);
+            if (*cp == ',') {
+                char *endptr;
+                cp++;
+                session->engineTime = strtoul(cp, &endptr, 10);
+                if (errno || cp == endptr) {
+                    fprintf(stderr, "Need engine time after \"-Z engineBoot,\".\n");
+                    return (-1);
+                }
+            }
             /*
              * Handle previous '-Z boot time' syntax 
              */
-            else if ((optind < argc) && isdigit(argv[optind][0]))
-                session->engineTime = strtoul(argv[optind], NULL, 10);
-            else {
-                fprintf(stderr, "Need engine time value after -Z flag.\n");
+            else if (optind < argc) {
+                session->engineTime = strtoul(argv[optind], &cp, 10);
+                if (errno || cp == argv[optind]) {
+                    fprintf(stderr, "Need engine time after \"-Z engineBoot\".\n");
+                    return (-1);
+                }
+            } else {
+                fprintf(stderr, "Need engine time after \"-Z engineBoot\".\n");
                 return (-1);
             }
             break;
@@ -505,7 +517,7 @@ snmp_parse_args(int argc,
             break;
 
         case 'a':
-#ifndef DISABLE_MD5
+#ifndef NETSNMP_DISABLE_MD5
             if (!strcasecmp(optarg, "MD5")) {
                 session->securityAuthProto = usmHMACMD5AuthProtocol;
                 session->securityAuthProtoLen = USM_AUTH_PROTO_MD5_LEN;
@@ -524,7 +536,7 @@ snmp_parse_args(int argc,
 
         case 'x':
             testcase = 0;
-#ifndef DISABLE_DES
+#ifndef NETSNMP_DISABLE_DES
             if (!strcasecmp(optarg, "DES")) {
                 testcase = 1;
                 session->securityPrivProto = usmDESPrivProtocol;
@@ -611,14 +623,14 @@ snmp_parse_args(int argc,
          * compile time default version 
          */
         if (!session->version) {
-            switch (DEFAULT_SNMP_VERSION) {
-#ifndef DISABLE_SNMPV1
+            switch (NETSNMP_DEFAULT_SNMP_VERSION) {
+#ifndef NETSNMP_DISABLE_SNMPV1
             case 1:
                 session->version = SNMP_VERSION_1;
                 break;
 #endif
 
-#ifndef DISABLE_SNMPV2C
+#ifndef NETSNMP_DISABLE_SNMPV2C
             case 2:
                 session->version = SNMP_VERSION_2c;
                 break;
@@ -633,7 +645,7 @@ snmp_parse_args(int argc,
                 return(-2);
             }
         } else {
-#ifndef DISABLE_SNMPV1
+#ifndef NETSNMP_DISABLE_SNMPV1
             if (session->version == NETSNMP_DS_SNMP_VERSION_1)  /* bogus value.  version 1 actually = 0 */
                 session->version = SNMP_VERSION_1;
 #endif
@@ -655,7 +667,7 @@ snmp_parse_args(int argc,
                 snmp_duplicate_objid(def, session->securityAuthProtoLen);
         }
         if (session->securityAuthProto == NULL) {
-#ifndef DISABLE_MD5
+#ifndef NETSNMP_DISABLE_MD5
             /*
              * assume MD5
              */
@@ -696,7 +708,7 @@ snmp_parse_args(int argc,
             /*
              * assume DES 
              */
-#ifndef DISABLE_DES
+#ifndef NETSNMP_DISABLE_DES
             session->securityPrivProto =
                 snmp_duplicate_objid(usmDESPrivProtocol,
                                      USM_PRIV_PROTO_DES_LEN);
@@ -729,17 +741,17 @@ snmp_parse_args(int argc,
     }
     session->peername = argv[optind++]; /* hostname */
 
-#if !defined(DISABLE_SNMPV1) || !defined(DISABLE_SNMPV2C)
+#if !defined(NETSNMP_DISABLE_SNMPV1) || !defined(NETSNMP_DISABLE_SNMPV2C)
     /*
      * If v1 or v2c, check community has been set, either by a -c option above,
      * or via a default token somewhere.  
      * If neither, it will be taken from the incoming request PDU.
      */
 
-#if defined(DISABLE_SNMPV1)
+#if defined(NETSNMP_DISABLE_SNMPV1)
     if (session->version == SNMP_VERSION_2c)
 #else 
-#if defined(DISABLE_SNMPV2C)
+#if defined(NETSNMP_DISABLE_SNMPV2C)
     if (session->version == SNMP_VERSION_1)
 #else
     if (session->version == SNMP_VERSION_1 ||
