@@ -45,32 +45,32 @@
 #include <dmalloc.h>
 #endif
 
-#ifdef HEIMDAL
-#ifndef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_HEIMDAL
+#ifndef NETSNMP_USE_KERBEROS_MIT
 #define OLD_HEIMDAL
-#endif 				/* ! MIT_NEW_CRYPTO */
-#endif 				/* HEIMDAL */
+#endif 				/* ! NETSNMP_USE_KERBEROS_MIT */
+#endif 				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 
-#ifdef HEIMDAL
+#ifdef NETSNMP_USE_KERBEROS_HEIMDAL
 #define oid heimdal_oid_renamed
-#endif				/* HEIMDAL */
+#endif				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 #include <krb5.h>
 #include <com_err.h>
-#ifdef HEIMDAL
+#ifdef NETSNMP_USE_KERBEROS_HEIMDAL
 #undef oid
-#endif				/* HEIMDAL */
+#endif				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 
-#ifdef HEIMDAL
+#ifdef NETSNMP_USE_KERBEROS_HEIMDAL
 #define CHECKSUM_TYPE(x)	(x)->cksumtype
 #define CHECKSUM_CONTENTS(x)	((char *)((x)->checksum.data))
 #define CHECKSUM_LENGTH(x)	(x)->checksum.length
 #define TICKET_CLIENT(x)	(x)->client
-#else				/* HEIMDAL */
+#else				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 #define CHECKSUM_TYPE(x)	(x)->checksum_type
 #define CHECKSUM_CONTENTS(x)	(x)->contents
 #define CHECKSUM_LENGTH(x)	(x)->length
 #define TICKET_CLIENT(x)	(x)->enc_part2->client
-#endif				/* HEIMDAL */
+#endif				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 
 #include <net-snmp/output_api.h>
 #include <net-snmp/config_api.h>
@@ -449,16 +449,16 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
     int             retval = SNMPERR_SUCCESS;
     krb5_data       outdata, ivector;
     krb5_keyblock  *subkey = NULL;
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     krb5_data       input;
     krb5_enc_data   output;
     unsigned int    numcksumtypes;
     krb5_cksumtype  *cksumtype_array;
-#elif defined OLD_HEIMDAL	/* MIT_NEW_CRYPTO */
+#elif defined OLD_HEIMDAL	/* NETSNMP_USE_KERBEROS_MIT */
     krb5_crypto heim_crypto = NULL;
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
     krb5_encrypt_block eblock;
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
     size_t          blocksize, encrypted_length;
     unsigned char  *encrypted_data = NULL;
     int             zero = 0, i;
@@ -609,7 +609,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
          * length of the PDU.
          */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
         retcode = krb5_c_encrypt_length(kcontext, subkey->enctype,
                                         parms->scopedPduLen,
                                         &encrypted_length);
@@ -633,7 +633,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
         }
 	encrypted_length = krb5_get_wrapped_length(kcontext, heim_crypto,
 						   parms->scopedPduLen);
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
         krb5_use_enctype(kcontext, &eblock, subkey->enctype);
         retcode = krb5_process_key(kcontext, &eblock, subkey);
@@ -648,7 +648,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
 
         encrypted_length = krb5_encrypt_size(parms->scopedPduLen,
                                              eblock.crypto_entry);
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
 #ifndef OLD_HEIMDAL /* since heimdal allocs the space for us */
         encrypted_data = malloc(encrypted_length);
@@ -659,9 +659,9 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
                         "buffer: %s\n", parms->scopedPduLen,
                         strerror(errno)));
             retval = SNMPERR_MALLOC;
-#ifndef MIT_NEW_CRYPTO
+#ifndef NETSNMP_USE_KERBEROS_MIT
             krb5_finish_key(kcontext, &eblock);
-#endif                          /* ! MIT_NEW_CRYPTO */
+#endif                          /* ! NETSNMP_USE_KERBEROS_MIT */
 
             goto error;
         }
@@ -673,7 +673,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
          * of the encryption method).
          */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
 
         retcode = krb5_c_block_size(kcontext, subkey->enctype, &blocksize);
 
@@ -685,13 +685,13 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
             retval = SNMPERR_KRB5;
             goto error;
         }
-#elif defined (OLD_HEIMDAL)	/* MIT_NEW_CRYPTO */
-#else                           /* MIT_NEW_CRYPTO */
+#elif defined (OLD_HEIMDAL)	/* NETSNMP_USE_KERBEROS_MIT */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
         blocksize =
             krb5_enctype_array[subkey->enctype]->system->block_length;
 
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
 #ifndef OLD_HEIMDAL	/* since allocs the space for us */
         ivector.data = malloc(blocksize);
@@ -711,7 +711,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
          * Finally!  Do the encryption!
          */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
 
         input.data = (char *) parms->scopedPdu;
         input.length = parms->scopedPduLen;
@@ -722,7 +722,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
             krb5_c_encrypt(kcontext, subkey, KSM_KEY_USAGE_ENCRYPTION,
                            &ivector, &input, &output);
 
-#elif defined OLD_HEIMDAL /* MIT_NEW_CRYPTO */
+#elif defined OLD_HEIMDAL /* NETSNMP_USE_KERBEROS_MIT */
 
 	krb5_data_zero(&encrypted_scoped_pdu);
 	retcode = krb5_encrypt(kcontext, heim_crypto, KSM_KEY_USAGE_ENCRYPTION,
@@ -733,7 +733,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
 		encrypted_data = encrypted_scoped_pdu.data;
 		krb5_data_zero(&encrypted_scoped_pdu);
 	}
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
         retcode = krb5_encrypt(kcontext, (krb5_pointer) parms->scopedPdu,
                                (krb5_pointer) encrypted_data,
@@ -741,7 +741,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
 
         krb5_finish_key(kcontext, &eblock);
 
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
         if (retcode) {
             DEBUGMSGTL(("ksm", "KSM: krb5_encrypt failed: %s\n",
@@ -855,7 +855,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
      * one of the "approved" ones.
      */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     retcode = krb5_c_keyed_checksum_types(kcontext, subkey->enctype,
                                           &numcksumtypes, &cksumtype_array);
 
@@ -899,7 +899,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
 
     CHECKSUM_LENGTH(&pdu_checksum) = blocksize;
 
-#else /* MIT_NEW_CRYPTO */
+#else /* NETSNMP_USE_KERBEROS_MIT */
     if (ksm_state)
         cksumtype = ksm_state->cksumtype;
     else
@@ -972,7 +972,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
     }
 #endif			/* OLD_HEIMDAL */
 
-#endif /* MIT_NEW_CRYPTO */
+#endif /* NETSNMP_USE_KERBEROS_MIT */
 
     /*
      * Note that here, we're just leaving blank space for the checksum;
@@ -1081,7 +1081,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
         goto error;
     }
 #endif					/* ! OLD_HEIMDAL */
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
 
     input.data = (char *) (*wholeMsg + *parms->wholeMsgLen - *offset);
     input.length = *offset;
@@ -1089,13 +1089,13 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
                                        KSM_KEY_USAGE_CHECKSUM, &input,
                                        &pdu_checksum);
 
-#elif defined(OLD_HEIMDAL)	/* MIT_NEW_CRYPTO */
+#elif defined(OLD_HEIMDAL)	/* NETSNMP_USE_KERBEROS_MIT */
 
 	retcode = krb5_create_checksum(kcontext, heim_crypto,
 				       KSM_KEY_USAGE_CHECKSUM, cksumtype,
 				       *wholeMsg + *parms->wholeMsgLen
 				       - *offset, *offset, &pdu_checksum);
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
     retcode = krb5_calculate_checksum(kcontext, cksumtype, *wholeMsg +
 				      *parms->wholeMsgLen - *offset,
@@ -1103,7 +1103,7 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
                                       (krb5_pointer) subkey->contents,
                                       subkey->length, &pdu_checksum);
 
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
     if (retcode) {
         DEBUGMSGTL(("ksm", "Calculate checksum failed: %s\n",
@@ -1147,11 +1147,11 @@ ksm_rgenerate_out_msg(struct snmp_secmod_outgoing_params *parms)
   error:
 
     if (CHECKSUM_CONTENTS(&pdu_checksum))
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
         krb5_free_checksum_contents(kcontext, &pdu_checksum);
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
         free(CHECKSUM_CONTENTS(&pdu_checksum));
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
     if (ivector.data)
         free(ivector.data);
@@ -1205,16 +1205,16 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
     krb5_data       ap_req, ivector;
     krb5_flags      flags;
     krb5_keyblock  *subkey = NULL;
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     krb5_data       input, output;
     krb5_boolean    valid;
     krb5_enc_data   in_crypt;
-#elif defined OLD_HEIMDAL	/* MIT_NEW_CRYPTO */
+#elif defined OLD_HEIMDAL	/* NETSNMP_USE_KERBEROS_MIT */
     krb5_data output;
     krb5_crypto heim_crypto = NULL;
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
     krb5_encrypt_block eblock;
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
     krb5_ticket    *ticket = NULL;
     int             retval = SNMPERR_SUCCESS, response = 0;
     size_t          length =
@@ -1269,7 +1269,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
 
     cksumtype = temp;
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     if (!krb5_c_valid_cksumtype(cksumtype)) {
         DEBUGMSGTL(("ksm", "Invalid checksum type (%d)\n", cksumtype));
 
@@ -1293,7 +1293,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         retval = SNMPERR_KRB5;
         goto error;
     }
-#else /* ! MIT_NEW_CRYPTO */
+#else /* ! NETSNMP_USE_KERBEROS_MIT */
 #ifdef OLD_HEIMDAL
     /* kludge */
     if (krb5_checksumsize(kcontext, cksumtype, &cksumlength)) {
@@ -1330,7 +1330,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         retval = SNMPERR_KRB5;
         goto error;
     }
-#endif /* MIT_NEW_CRYPTO */
+#endif /* NETSNMP_USE_KERBEROS_MIT */
 
     CHECKSUM_TYPE(&checksum) = cksumtype;
 
@@ -1420,9 +1420,9 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
      */
 
     if (ap_req.length
-#ifndef HEIMDAL
+#ifndef NETSNMP_USE_KERBEROS_HEIMDAL
         && (ap_req.data[0] == 0x6e || ap_req.data[0] == 0x4e)) {
-#else				/* HEIMDAL */
+#else				/* NETSNMP_USE_KERBEROS_HEIMDAL */
         && (((char *)ap_req.data)[0] == 0x6e || ((char *)ap_req.data)[0] == 0x4e)) {
 #endif
 
@@ -1513,13 +1513,13 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
             goto error;
         }
 
-#ifndef HEIMDAL
+#ifndef NETSNMP_USE_KERBEROS_HEIMDAL
     } else if (ap_req.length && (ap_req.data[0] == 0x6f ||
                                  ap_req.data[0] == 0x4f)) {
-#else				/* HEIMDAL */
+#else				/* NETSNMP_USE_KERBEROS_HEIMDAL */
     } else if (ap_req.length && (((char *)ap_req.data)[0] == 0x6f ||
                                  ((char *)ap_req.data)[0] == 0x4f)) {
-#endif				/* HEIMDAL */
+#endif				/* NETSNMP_USE_KERBEROS_HEIMDAL */
         /*
          * Looks like a response; let's see if we've got that auth_context
          * in our cache.
@@ -1571,10 +1571,10 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         }
 
     } else {
-#ifndef HEIMDAL
+#ifndef NETSNMP_USE_KERBEROS_HEIMDAL
         DEBUGMSGTL(("ksm", "Unknown Kerberos message type (%02x)\n",
                     ap_req.data[0]));
-#else 				/* HEIMDAL */
+#else 				/* NETSNMP_USE_KERBEROS_HEIMDAL */
 	 DEBUGMSGTL(("ksm", "Unknown Kerberos message type (%02x)\n",
                     ((char *)ap_req.data)[0]));
 #endif
@@ -1583,14 +1583,14 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         goto error;
     }
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     input.data = (char *) parms->wholeMsg;
     input.length = parms->wholeMsgLen;
 
     retcode =
         krb5_c_verify_checksum(kcontext, subkey, KSM_KEY_USAGE_CHECKSUM,
                                &input, &checksum, &valid);
-#elif defined(OLD_HEIMDAL)	/* MIT_NEW_CRYPTO */
+#elif defined(OLD_HEIMDAL)	/* NETSNMP_USE_KERBEROS_MIT */
     retcode = krb5_crypto_init(kcontext, subkey, 0, &heim_crypto);
     if (retcode) {
             DEBUGMSGTL(("ksm", "krb5_crypto_init failed: %s\n",
@@ -1602,12 +1602,12 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
     retcode = krb5_verify_checksum(kcontext, heim_crypto,
 				   KSM_KEY_USAGE_CHECKSUM, parms->wholeMsg,
 				   parms->wholeMsgLen, &checksum);
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
     retcode = krb5_verify_checksum(kcontext, cksumtype, &checksum,
                                    parms->wholeMsg, parms->wholeMsgLen,
                                    (krb5_pointer) subkey->contents,
                                    subkey->length);
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
     if (retcode) {
         DEBUGMSGTL(("ksm", "KSM checksum verification failed: %s\n",
@@ -1622,7 +1622,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
      * to check to see if "valid" is false.
      */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
     if (!valid) {
         DEBUGMSGTL(("ksm", "Computed checksum did not match supplied "
                     "checksum!\n"));
@@ -1631,7 +1631,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
             ("Computed checksum did not match supplied checksum");
         goto error;
     }
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
     /*
      * Handle an encrypted PDU.  Note that it's an OCTET_STRING of the
@@ -1664,7 +1664,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
          * of the encryption method).
          */
 
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
 
         retcode = krb5_c_block_size(kcontext, subkey->enctype, &blocksize);
 
@@ -1676,13 +1676,13 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
             retval = SNMPERR_KRB5;
             goto error;
         }
-#elif defined(OLD_HEIMDAL)	/* MIT_NEW_CRYPTO */
-#else                           /* MIT_NEW_CRYPTO */
+#elif defined(OLD_HEIMDAL)	/* NETSNMP_USE_KERBEROS_MIT */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
         blocksize =
             krb5_enctype_array[subkey->enctype]->system->block_length;
 
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
 #ifndef OLD_HEIMDAL
         ivector.data = malloc(blocksize);
@@ -1697,7 +1697,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         ivector.length = blocksize;
         memset(ivector.data, 0, blocksize);
 
-#ifndef MIT_NEW_CRYPTO
+#ifndef NETSNMP_USE_KERBEROS_MIT
 
         krb5_use_enctype(kcontext, &eblock, subkey->enctype);
 
@@ -1710,7 +1710,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
             retval = SNMPERR_KRB5;
             goto error;
         }
-#endif                          /* !MIT_NEW_CRYPTO */
+#endif                          /* !NETSNMP_USE_KERBEROS_MIT */
 
 #endif /* ! OLD_HEIMDAL */
 
@@ -1719,14 +1719,14 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
                         "decrypt but only %d bytes available\n", length,
                         *parms->scopedPduLen));
             retval = SNMPERR_TOO_LONG;
-#ifndef MIT_NEW_CRYPTO
+#ifndef NETSNMP_USE_KERBEROS_MIT
 #ifndef OLD_HEIMDAL
             krb5_finish_key(kcontext, &eblock);
 #endif                          /* ! OLD_HEIMDAL */
-#endif                          /* ! MIT_NEW_CRYPTO */
+#endif                          /* ! NETSNMP_USE_KERBEROS_MIT */
             goto error;
         }
-#ifdef MIT_NEW_CRYPTO
+#ifdef NETSNMP_USE_KERBEROS_MIT
         in_crypt.ciphertext.data = (char *) current;
         in_crypt.ciphertext.length = length;
         in_crypt.enctype = subkey->enctype;
@@ -1736,7 +1736,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
         retcode =
             krb5_c_decrypt(kcontext, subkey, KSM_KEY_USAGE_ENCRYPTION,
                            &ivector, &in_crypt, &output);
-#elif defined (OLD_HEIMDAL)	/* MIT_NEW_CRYPTO */
+#elif defined (OLD_HEIMDAL)	/* NETSNMP_USE_KERBEROS_MIT */
 	retcode = krb5_decrypt(kcontext, heim_crypto, KSM_KEY_USAGE_ENCRYPTION,
 			       current, length, &output);
 	if (retcode == 0) {
@@ -1744,7 +1744,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
 		*parms->scopedPduLen = output.length;
 		krb5_data_zero(&output);
 	}
-#else                           /* MIT_NEW_CRYPTO */
+#else                           /* NETSNMP_USE_KERBEROS_MIT */
 
         retcode = krb5_decrypt(kcontext, (krb5_pointer) current,
                                *parms->scopedPdu, length, &eblock,
@@ -1752,7 +1752,7 @@ ksm_process_in_msg(struct snmp_secmod_incoming_params *parms)
 
         krb5_finish_key(kcontext, &eblock);
 
-#endif                          /* MIT_NEW_CRYPTO */
+#endif                          /* NETSNMP_USE_KERBEROS_MIT */
 
         if (retcode) {
             DEBUGMSGTL(("ksm", "Decryption failed: %s\n",
